;;; mgp.el --- Generic mode for magicpoint files

;; Copyright (C) 2002 Free Software Foundation, Inc.

;; Author:  Christian Egli <christian.egli@stest.ch>
;; Created: 2001-3-12
;; Keywords: generic, comment, font-lock, magicpoint

;; This file is part of GNU Emacs.

;; GNU Emacs is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; GNU Emacs is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Commentary:

;; This package is a generic mode for editing Magic Point source code.

;; Magic Point is an X11 based presentation tool. It is designed to
;; make simple presentations easy while to make complicated
;; presentations possible. Its presentation file (whose suffix is
;; typically .mgp) is just text so that you can create presentation
;; files quickly with your favorite editor (i.e. Emacs).

;;; Code:

(require 'generic)
(require 'font-lock)

(defgroup magicpoint nil
  "Magic Point mode."
  :group 'wp
  :prefix "magicpoint-")

(defcustom magicpoint-command "mgp"
  "*Command used by magicpoint-mode to display a `.mgp' file."
  :type 'file
  :group 'magicpoint)

(defcustom magicpoint-command-switches "-o"
  "*List of additional options for `magicpoint-command'."
  :type 'string
  :group 'magicpoint)

(defvar magicpoint-mode-keymap (copy-keymap text-mode-map)
  "Keymap for `magicpoint-mode'.")

;;; mgp
(define-generic-mode 'magicpoint-mode
   '(?# ?\n)
   '("%vfcap" "%again" "%back" "%bar" "%bgrad" "%bimage" "%center"
     "%cont" "%default" "%deffont" "%embed" "%endembed" "%endfilter"
     "%filter" "%font" "%fore" "%hgap" "%icon" "%image" "%include"
     "%lcutin" "%left" "%leftfill" "%mark" "%newimage" "%nodefault"
     "%noop" "%page" "%pause" "%pcache" "%prefix" "%rcutin" "%right"
     "%shrink" "%size" "%system" "%tab" "%tfdir" "%tfont" "%tfont0"
     "%tmfont" "%vfcap" "%vfont" "%vgap" "%xfont")
   nil
   (list "\\.mgp\\'")
   (list
    (function
     (lambda ()
       (make-local-variable 'compile-command)
       (make-local-variable 'compilation-read-command)
       (setq compilation-read-command nil)
       (setq compile-command
             (concat magicpoint-command " " magicpoint-command-switches " "
                     buffer-file-name))
       (define-key magicpoint-mode-keymap "\C-c\C-c" 'compile)
       (use-local-map magicpoint-mode-keymap))))
   "Generic mode for Magic Point files.")

;;; mgp.el ends here
